% Auto-generated chapter 7 for muslim
% Hadiths in this chapter: 93

\hadithdefcmd{muslim}{1951}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَمُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ، قَالاَ أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا لَيْثٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا أَرَادَ أَحَدُكُمْ أَنْ يَأْتِيَ الْجُمُعَةَ فَلْيَغْتَسِلْ ‏"‏ ‏.‏\hadithno{1951}\hadithtrans{Abdullah is reported to have heard Allah's Messenger (ﷺ) as saying:When any one of you intends to come for Jumu'a prayer, he should take a bath}}
\hadithdefcmd{muslim}{1952}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا ابْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنِ ابْنِ، شِهَابٍ عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ وَهُوَ قَائِمٌ عَلَى الْمِنْبَرِ ‏ "‏ مَنْ جَاءَ مِنْكُمُ الْجُمُعَةَ فَلْيَغْتَسِلْ ‏"‏ ‏.‏\hadithno{1952}\hadithtrans{Abdullah b. Umar is reported to have said that The Messenger of Allah (may peace be up on him) was standing on the pulpit when he said this:He who comes for Jumu'a he should take a bath}}
\hadithdefcmd{muslim}{1953}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي ابْنُ شِهَابٍ، عَنْ سَالِمٍ، وَعَبْدِ اللَّهِ، ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم .‏ بِمِثْلِهِ ‏.‏\hadithno{1953}\hadithtrans{This hadith has been narrated by Ibn Umar by another chain of transmitters}}
\hadithdefcmd{muslim}{1954}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{1954}\hadithtrans{Abdullah (b. Umar) reported on the authority of his father that he heard like this from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{1955}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، ‏.‏ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، بَيْنَا هُوَ يَخْطُبُ النَّاسَ يَوْمَ الْجُمُعَةِ دَخَلَ رَجُلٌ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَنَادَاهُ عُمَرُ أَيَّةُ سَاعَةٍ هَذِهِ فَقَالَ إِنِّي شُغِلْتُ الْيَوْمَ فَلَمْ أَنْقَلِبْ إِلَى أَهْلِي حَتَّى سَمِعْتُ النِّدَاءَ فَلَمْ أَزِدْ عَلَى أَنْ تَوَضَّأْتُ ‏.‏ قَالَ عُمَرُ وَالْوُضُوءَ أَيْضًا وَقَدْ عَلِمْتَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَأْمُرُ بِالْغُسْلِ ‏.‏\hadithno{1955}\hadithtrans{Abdullah (b. 'Umar) reported from his father that while he was addressing the people on Friday (sermon), a person, one of the Companions of the Messenger of Allah (ﷺ), entered (the mosque). Umar said to him loudly:What is this hour (for attending the prayer)? He said: I was busy today and I did not return to my house when I heard the call (to Friday prayer), and I did no more but performed ablution only. Upon this Umar said: just ablution! You know that the Messenger of Allah (ﷺ) commanded (us) to take a bath (on Friday)}}
\hadithdefcmd{muslim}{1956}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ الأَوْزَاعِيِّ، قَالَ حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنِي أَبُو هُرَيْرَةَ، قَالَ بَيْنَمَا عُمَرُ بْنُ الْخَطَّابِ يَخْطُبُ النَّاسَ يَوْمَ الْجُمُعَةِ إِذْ دَخَلَ عُثْمَانُ بْنُ عَفَّانَ فَعَرَّضَ بِهِ عُمَرُ فَقَالَ مَا بَالُ رِجَالٍ يَتَأَخَّرُونَ بَعْدَ النِّدَاءِ ‏.‏ فَقَالَ عُثْمَانُ يَا أَمِيرَ الْمُؤْمِنِينَ مَا زِدْتُ حِينَ سَمِعْتُ النِّدَاءَ أَنْ تَوَضَّأْتُ ثُمَّ أَقْبَلْتُ ‏.‏ فَقَالَ عُمَرُ وَالْوُضُوءَ أَيْضًا أَلَمْ تَسْمَعُوا رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا جَاءَ أَحَدُكُمْ إِلَى الْجُمُعَةِ فَلْيَغْتَسِلْ ‏"‏ ‏.‏\hadithno{1956}\hadithtrans{Abu Huraira reported:Umar b. Khattab was delivering a sermon to the people on Friday when 'Uthman b. 'Affan came there. 'Umar hinting to him said: What would become of those persons who come after the call to prayer? Upon this 'Uthman said: Commander of the faithful, I did no more than this that after listening to the call, I performed ablution and came (to the mosque). 'Umar said: Just ablution! Did you not hear the Messenger of Allah (my peace be upon him) say this: When any one of you comes for Jumu'a, he should take a bath}}
\hadithdefcmd{muslim}{1957}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ عَطَاءِ، بْنِ يَسَارٍ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْغُسْلُ يَوْمَ الْجُمُعَةِ وَاجِبٌ عَلَى كُلِّ مُحْتَلِمٍ ‏"‏ ‏.‏\hadithno{1957}\hadithtrans{Sa'id al-Khudri reported Allah's Messenger (ﷺ) as saying:Taking a bath on Friday is essential for every adult person}}
\hadithdefcmd{muslim}{1958}{حَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَأَحْمَدُ بْنُ عِيسَى، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، أَنَّ مُحَمَّدَ بْنَ جَعْفَرٍ، حَدَّثَهُ عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ كَانَ النَّاسُ يَنْتَابُونَ الْجُمُعَةَ مِنْ مَنَازِلِهِمْ مِنَ الْعَوَالِي فَيَأْتُونَ فِي الْعَبَاءِ وَيُصِيبُهُمُ الْغُبَارُ فَتَخْرُجُ مِنْهُمُ الرِّيحُ فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم إِنْسَانٌ مِنْهُمْ وَهُوَ عِنْدِي فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ أَنَّكُمْ تَطَهَّرْتُمْ لِيَوْمِكُمْ هَذَا ‏"‏ ‏.‏\hadithno{1958}\hadithtrans{Aisha reported:The people came for Jumu'a prayer from their houses in the neighbouring villages dressed in woollen garments on which dust was settled and this emitted a foul smell. A person among them (those who were dressed so) came to the Messenger of Allah (ﷺ) while he was in my house. The Messenger of Allah (may peace he upon him) said to him: Were you to cleanse yourselves on this day}}
\hadithdefcmd{muslim}{1959}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ كَانَ النَّاسُ أَهْلَ عَمَلٍ وَلَمْ يَكُنْ لَهُمْ كُفَاةٌ فَكَانُوا يَكُونُ لَهُمْ تَفَلٌ فَقِيلَ لَهُمْ لَوِ اغْتَسَلْتُمْ يَوْمَ الْجُمُعَةِ ‏.‏\hadithno{1959}\hadithtrans{Aisha reported:The people (mostly) were workers and they had no servants. Ill-smell thus emitted out of them. It was said to them: Were you to take bath on Friday}}
\hadithdefcmd{muslim}{1960}{وَحَدَّثَنَا عَمْرُو بْنُ سَوَّادٍ الْعَامِرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنَا عَمْرُو بْنُ، الْحَارِثِ أَنَّ سَعِيدَ بْنَ أَبِي هِلاَلٍ، وَبُكَيْرَ بْنَ الأَشَجِّ، حَدَّثَاهُ عَنْ أَبِي بَكْرِ بْنِ الْمُنْكَدِرِ، عَنْ عَمْرِو، بْنِ سُلَيْمٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ غُسْلُ يَوْمِ الْجُمُعَةِ عَلَى كُلِّ مُحْتَلِمٍ وَسِوَاكٌ وَيَمَسُّ مِنَ الطِّيبِ مَا قَدَرَ عَلَيْهِ ‏"‏ ‏.‏ إِلاَّ أَنَّ بُكَيْرًا لَمْ يَذْكُرْ عَبْدَ الرَّحْمَنِ وَقَالَ فِي الطِّيبِ وَلَوْ مِنْ طِيبِ الْمَرْأَةِ ‏.‏\hadithno{1960}\hadithtrans{Abd al-Rahman son of Abd Sa'id al-Khudri reported on the authority of his father that the Messenger of Allah (ﷺ) said:Bathing on Friday for every adult, using of Miswak and applying some perfume, that is available-these are essential. So far as the perfume is concerned, it may be that used by a lady}}
\hadithdefcmd{muslim}{1961}{حَدَّثَنَا حَسَنٌ الْحُلْوَانِيُّ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، ح وَحَدَّثَنِي مُحَمَّدُ، بْنُ رَافِعٍ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي إِبْرَاهِيمُ بْنُ مَيْسَرَةَ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ ذَكَرَ قَوْلَ النَّبِيِّ صلى الله عليه وسلم فِي الْغُسْلِ يَوْمَ الْجُمُعَةِ ‏.‏ قَالَ طَاوُسٌ فَقُلْتُ لاِبْنِ عَبَّاسٍ وَيَمَسُّ طِيبًا أَوْ دُهْنًا إِنْ كَانَ عِنْدَ أَهْلِهِ قَالَ لاَ أَعْلَمُهُ ‏.‏\hadithno{1961}\hadithtrans{Tawus reported that Ibn Abbas narrated the words of the Messenger of Allah (ﷺ) about taking bath on Friday. Tawus said:I asked Ibn Abbas it one should apply to oneself perfume or oil which is available with his wife. He (Ibn Abbas) said: I do not know of it}}
\hadithdefcmd{muslim}{1962}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ، ح وَحَدَّثَنَا هَارُونُ بْنُ عَبْدِ، اللَّهِ حَدَّثَنَا الضَّحَّاكُ بْنُ مَخْلَدٍ، كِلاَهُمَا عَنِ ابْنِ جُرَيْجٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{1962}\hadithtrans{This hadith has been narrated by Ibn Juraij with the came chain of transmitters}}
\hadithdefcmd{muslim}{1963}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ حَقٌّ لِلَّهِ عَلَى كُلِّ مُسْلِمٍ أَنْ يَغْتَسِلَ فِي كُلِّ سَبْعَةِ أَيَّامٍ يَغْسِلُ رَأْسَهُ وَجَسَدَهُ ‏"‏ ‏.‏\hadithno{1963}\hadithtrans{Abu Huraira reported that the Messenger of Allah (ﷺ) said. it is the right of Allah upon every Muslim that he should take a bath (at least) on one day (Friday) during the seven days (of the week) and he should wash his head and body}}
\hadithdefcmd{muslim}{1964}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، فِيمَا قُرِئَ عَلَيْهِ عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اغْتَسَلَ يَوْمَ الْجُمُعَةِ غُسْلَ الْجَنَابَةِ ثُمَّ رَاحَ فَكَأَنَّمَا قَرَّبَ بَدَنَةً وَمَنْ رَاحَ فِي السَّاعَةِ الثَّانِيَةِ فَكَأَنَّمَا قَرَّبَ بَقَرَةً وَمَنْ رَاحَ فِي السَّاعَةِ الثَّالِثَةِ فَكَأَنَّمَا قَرَّبَ كَبْشًا أَقْرَنَ وَمَنْ رَاحَ فِي السَّاعَةِ الرَّابِعَةِ فَكَأَنَّمَا قَرَّبَ دَجَاجَةً وَمَنْ رَاحَ فِي السَّاعَةِ الْخَامِسَةِ فَكَأَنَّمَا قَرَّبَ بَيْضَةً فَإِذَا خَرَجَ الإِمَامُ حَضَرَتِ الْمَلاَئِكَةُ يَسْتَمِعُونَ الذِّكْرَ ‏"‏ ‏.‏\hadithno{1964}\hadithtrans{Abu Huraira reported that the Messenger of, Allah (ﷺ) said. He who takes a bath on Friday, the bath which is obligatory after the sexual discharge and then goes (to the mosque), he is like one who offers a she-camel as a sacrifice, and he who comes at the second hour would be like one who offers a cow, and he who comes at the third hour is live one who offers a ram with horns, and he who comes at the fourth hour is like one who offers a hen, and he who comes at the fifth hour is like one who offers an egg. And when the Imam comes out, the angels are also present and listen to the mention of God (the sermon)}}
\hadithdefcmd{muslim}{1965}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ، قَالَ ابْنُ رُمْحٍ أَخْبَرَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قُلْتَ لِصَاحِبِكَ أَنْصِتْ ‏.‏ يَوْمَ الْجُمُعَةِ وَالإِمَامُ يَخْطُبُ فَقَدْ لَغَوْتَ ‏"‏ ‏.‏\hadithno{1965}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:If you (even) ask your companion to be quiet on Friday while the Imam is delivering the sermon, you have in fact talked irrelevance}}
\hadithdefcmd{muslim}{1966}{وَحَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلُ بْنُ، خَالِدٍ عَنِ ابْنِ شِهَابٍ، عَنْ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، عَنْ عَبْدِ اللَّهِ بْنِ إِبْرَاهِيمَ بْنِ قَارِظٍ، وَعَنِ ابْنِ الْمُسَيَّبِ، أَنَّهُمَا حَدَّثَاهُ أَنَّ أَبَا هُرَيْرَةَ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{1966}\hadithtrans{A hadith like this has been narrated by Abu Huraira by another chain of transmitters}}
\hadithdefcmd{muslim}{1967}{وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي ابْنُ، شِهَابٍ بِالإِسْنَادَيْنِ جَمِيعًا فِي هَذَا الْحَدِيثِ ‏.‏ مِثْلَهُ غَيْرَ أَنَّ ابْنَ جُرَيْجٍ قَالَ إِبْرَاهِيمُ بْنُ عَبْدِ اللَّهِ بْنِ قَارِظٍ ‏.‏\hadithno{1967}\hadithtrans{Ibn Juraij narrated a similar Hadith (as no. 1965) from Ibn Shihab with both chains, except that Ibn Juraij said:"Ibrahim bin 'Abdullah bin Qariz}}
\hadithdefcmd{muslim}{1968}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قُلْتَ لِصَاحِبِكَ أَنْصِتْ ‏.‏ يَوْمَ الْجُمُعَةِ وَالإِمَامُ يَخْطُبُ فَقَدْ لَغِيتَ ‏"‏ ‏.‏ قَالَ أَبُو الزِّنَادِ هِيَ لُغَةُ أَبِي هُرَيْرَةَ وَإِنَّمَا هُوَ فَقَدْ لَغَوْتَ ‏.‏\hadithno{1968}\hadithtrans{The same hadith has been narrated by Abu Huraira, but instead of the word laghauta the word laghita has been used. Abu Zinad (one of the narrators) says that laghita is the dialect of Abu Huraira, whereas it is laghauta}}
\hadithdefcmd{muslim}{1969}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَكَرَ يَوْمَ الْجُمُعَةِ فَقَالَ ‏ "‏ فِيهِ سَاعَةٌ لاَ يُوَافِقُهَا عَبْدٌ مُسْلِمٌ وَهُوَ يُصَلِّي يَسْأَلُ اللَّهَ شَيْئًا إِلاَّ أَعْطَاهُ إِيَّاهُ ‏"‏ ‏.‏ زَادَ قُتَيْبَةُ فِي رِوَايَتِهِ وَأَشَارَ بِيَدِهِ يُقَلِّلُهَا\hadithno{1969}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There is a time on Friday at which no Muslim servant would pray and would ask Allah for a thing (that is good) but He would give it to him. Qutaiba pointed with the help of his hand that it (the time) is short}}
\hadithdefcmd{muslim}{1970}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَيُّوبُ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ أَبُو الْقَاسِمِ صلى الله عليه وسلم ‏ "‏ إِنَّ فِي الْجُمُعَةِ لَسَاعَةً لاَ يُوَافِقُهَا مُسْلِمٌ قَائِمٌ يُصَلِّي يَسْأَلُ اللَّهَ خَيْرًا إِلاَّ أَعْطَاهُ إِيَّاهُ." وَقَالَ بِيَدِهِ يُقَلِّلُهَا يُزَهِّدُهَا\hadithno{1970}\hadithtrans{Abu Huraira reported Abu'l-Qasim (the kunya of the Holy Prophet) (ﷺ) as saying:There is a time on Friday at which no Muslim would stand and pray and beg Allah for what Is good but He would give it to him; and he pointed with his hand that (this time) is short and narrow}}
\hadithdefcmd{muslim}{1971}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنِ ابْنِ عَوْنٍ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ أَبُو الْقَاسِمِ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{1971}\hadithtrans{A hadith like this has been narrated by Abu Huraira}}
\hadithdefcmd{muslim}{1972}{وَحَدَّثَنِي حُمَيْدُ بْنُ مَسْعَدَةَ الْبَاهِلِيُّ، حَدَّثَنَا بِشْرٌ، - يَعْنِي ابْنَ مُفَضَّلٍ - حَدَّثَنَا سَلَمَةُ، وَهُوَ ابْنُ عَلْقَمَةَ عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ أَبُو الْقَاسِمِ صلى الله عليه وسلم ‏بِمِثْلِهِ ‏.‏\hadithno{1972}\hadithtrans{This hadith has been narrated by Abu Huraira by another chain of transmitters}}
\hadithdefcmd{muslim}{1973}{وَحَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَلاَّمٍ الْجُمَحِيُّ، حَدَّثَنَا الرَّبِيعُ، - يَعْنِي ابْنَ مُسْلِمٍ - عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِنَّ فِي الْجُمُعَةِ لَسَاعَةً لا يُوَافِقُهَا مُسْلِمٌ يَسْأَلُ اللَّهَ فِيهَا خَيْرًا إِلاَّ أَعْطَاهُ إِيَّاهُ ‏"‏ ‏.‏ قَالَ وَهِيَ سَاعَةٌ خَفِيفَةٌ\hadithno{1973}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:"There is a time on Friday at which no Muslim would ask Allah for what is good but He would give it to him." And further said: "This is a very short time}}
\hadithdefcmd{muslim}{1974}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَلَمْ يَقُلْ وَهِيَ سَاعَةٌ خَفِيفَةٌ ‏.‏\hadithno{1974}\hadithtrans{Hammam b. Munabbih reported this hadith from Abu Huraira who reported from the Messenger of Allah (ﷺ) but he did not say:" That time is short}}
\hadithdefcmd{muslim}{1975}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَعَلِيُّ بْنُ خَشْرَمٍ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ مَخْرَمَةَ بْنِ، بُكَيْرٍ ح وَحَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَأَحْمَدُ بْنُ عِيسَى، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنَا مَخْرَمَةُ، عَنْ أَبِيهِ، عَنْ أَبِي بُرْدَةَ بْنِ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ قَالَ لِي عَبْدُ اللَّهِ بْنُ عُمَرَ أَسَمِعْتَ أَبَاكَ يُحَدِّثُ عَنْ رَسُولِ اللَّهِ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ فِي شَأْنِ سَاعَةِ الْجُمُعَةِ قَالَ: قُلْتُ نَعَمْ سَمِعْتُهُ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ يَقُولُ: «هِيَ مَا بَيْنَ أَنْ يَجْلِسَ الإِمَامُ إِلَى أَنْ تُقْضَى الصَّلاَةُ»\hadithno{1975}\hadithtrans{Abu Burda b. Abu Musa al-Ash'ari reported:'Abdullah b. Umar said to me: Did you hear anything from your father narrating something from the messenger of Allah (ﷺ) about the time on Friday? I said: Yes, I heard him say from the Messenger of Allah (ﷺ) (these words):" It is between the time when the Imam sits down and the end of the prayer}}
\hadithdefcmd{muslim}{1976}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عَبْدُ الرَّحْمَنِ الأَعْرَجُ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَيْرُ يَوْمٍ طَلَعَتْ عَلَيْهِ الشَّمْسُ يَوْمُ الْجُمُعَةِ فِيهِ خُلِقَ آدَمُ وَفِيهِ أُدْخِلَ الْجَنَّةَ وَفِيهِ أُخْرِجَ مِنْهَا ‏"‏ ‏.‏\hadithno{1976}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The best day on which the sun has risen is Friday; on it Adam was created, on it he was made to enter Paradise, on it he. was expelled from it}}
\hadithdefcmd{muslim}{1977}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُغِيرَةُ، - يَعْنِي الْحِزَامِيَّ - عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ خَيْرُ يَوْمٍ طَلَعَتْ عَلَيْهِ الشَّمْسُ يَوْمُ الْجُمُعَةِ فِيهِ خُلِقَ آدَمُ وَفِيهِ أُدْخِلَ الْجَنَّةَ وَفِيهِ أُخْرِجَ مِنْهَا وَلاَ تَقُومُ السَّاعَةُ إِلاَّ فِي يَوْمِ الْجُمُعَةِ ‏"‏ ‏.‏\hadithno{1977}\hadithtrans{Abu Huraira reported the Messenger of Allah (ﷺ) as saying:The best day on which the sun has risen is Friday; on it Adam was created. on it he was made to enter Paradise, on it he was expelled from it. And the last hour will take place on no day other than Friday}}
\hadithdefcmd{muslim}{1978}{وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَحْنُ الآخِرُونَ وَنَحْنُ السَّابِقُونَ يَوْمَ الْقِيَامَةِ بَيْدَ أَنَّ كُلَّ أُمَّةٍ أُوتِيَتِ الْكِتَابَ مِنْ قَبْلِنَا وَأُوتِينَاهُ مِنْ بَعْدِهِمْ ثُمَّ هَذَا الْيَوْمُ الَّذِي كَتَبَهُ اللَّهُ عَلَيْنَا هَدَانَا اللَّهُ لَهُ فَالنَّاسُ لَنَا فِيهِ تَبَعٌ الْيَهُودُ غَدًا وَالنَّصَارَى بَعْدَ غَدٍ ‏"‏ ‏.‏\hadithno{1978}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:We who are the last shall be the first on the Day of Resurrection, except that every Ummah was given the Book before us and we were given it after them. It was this day which Allah prescribed for us and guided us to it and the people came after us with regard to it, the Jews observing the next day and the Christians the day following that}}
\hadithdefcmd{muslim}{1979}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، وَابْنِ طَاوُسٍ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَحْنُ الآخِرُونَ وَنَحْنُ السَّابِقُونَ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{1979}\hadithtrans{A hadith like this has been narrated by Abu Huraira that the Messenger of Allah (ﷺ) said:We are the last and would be the first on the Day of Resurrection}}
\hadithdefcmd{muslim}{1980}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَحْنُ الآخِرُونَ الأَوَّلُونَ يَوْمَ الْقِيَامَةِ وَنَحْنُ أَوَّلُ مَنْ يَدْخُلُ الْجَنَّةَ بَيْدَ أَنَّهُمْ أُوتُوا الْكِتَابَ مِنْ قَبْلِنَا وَأُوتِينَاهُ مِنْ بَعْدِهِمْ فَاخْتَلَفُوا فَهَدَانَا اللَّهُ لِمَا اخْتَلَفُوا فِيهِ مِنَ الْحَقِّ فَهَذَا يَوْمُهُمُ الَّذِي اخْتَلَفُوا فِيهِ هَدَانَا اللَّهُ لَهُ - قَالَ يَوْمُ الْجُمُعَةِ - فَالْيَوْمُ لَنَا وَغَدًا لِلْيَهُودِ وَبَعْدَ غَدٍ لِلنَّصَارَى ‏"‏ ‏.‏\hadithno{1980}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:We are the last (but) we would be the first on the Day of Resurrection, and we would be the first to enter Paradise, but that they were given the Book before us and we were given after them. They disagreed and Allah guided us aright on whatever they disagreed regarding the truth. And it was this day of theirs about which they disagreed, but Allah guided us to it, and that is Friday for us; the next day is for the Jews and the day following for the Christians}}
\hadithdefcmd{muslim}{1981}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، أَخِي وَهْبِ بْنِ مُنَبِّهٍ قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ مُحَمَّدٍ، رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَحْنُ الآخِرُونَ السَّابِقُونَ يَوْمَ الْقِيَامَةِ بَيْدَ أَنَّهُمْ أُوتُوا الْكِتَابَ مِنْ قَبْلِنَا وَأُوتِينَاهُ مِنْ بَعْدِهِمْ وَهَذَا يَوْمُهُمُ الَّذِي فُرِضَ عَلَيْهِمْ فَاخْتَلَفُوا فِيهِ فَهَدَانَا اللَّهُ لَهُ فَهُمْ لَنَا فِيهِ تَبَعٌ فَالْيَهُودُ غَدًا وَالنَّصَارَى بَعْدَ غَدٍ ‏"‏ ‏.‏\hadithno{1981}\hadithtrans{Abu Huraira reported Muhammad, the Messenger of Allah (ﷺ), as saying:We who are the last would be the first on the Day of Resurrection but they (other Ummahs) were given the Book before us and we were given after them, and this was the day that was prescribed for them but they disagreed on it. And Allah guided us to it. and they came after us with regard to it, the Jews observing the next day and the Christians the day following that}}
\hadithdefcmd{muslim}{1982}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، وَوَاصِلُ بْنُ عَبْدِ الأَعْلَى، قَالاَ حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ أَبِي مَالِكٍ، الأَشْجَعِيِّ عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، وَعَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ حُذَيْفَةَ، قَالاَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَضَلَّ اللَّهُ عَنِ الْجُمُعَةِ مَنْ كَانَ قَبْلَنَا فَكَانَ لِلْيَهُودِ يَوْمُ السَّبْتِ وَكَانَ لِلنَّصَارَى يَوْمُ الأَحَدِ فَجَاءَ اللَّهُ بِنَا فَهَدَانَا اللَّهُ لِيَوْمِ الْجُمُعَةِ فَجَعَلَ الْجُمُعَةَ وَالسَّبْتَ وَالأَحَدَ وَكَذَلِكَ هُمْ تَبَعٌ لَنَا يَوْمَ الْقِيَامَةِ نَحْنُ الآخِرُونَ مِنْ أَهْلِ الدُّنْيَا وَالأَوَّلُونَ يَوْمَ الْقِيَامَةِ الْمَقْضِيُّ لَهُمْ قَبْلَ الْخَلاَئِقِ ‏"‏ ‏.‏ وَفِي رِوَايَةِ وَاصِلٍ الْمَقْضِيُّ بَيْنَهُمْ ‏.‏\hadithno{1982}\hadithtrans{It is narrated by Abu Huraira and Huraira that the Messenger of Allah (ﷺ) said:It was Friday from which Allah diverted those who were before us. For the Jews (the day set aside for prayer) was Sabt (Saturday), and for the Christians it was Sunday. And Allah turned towards us and guided us to Friday (as the day of prayer) for us. In fact, He (Allah) made Friday, Saturday and Sunday (as days of prayer). In this order would they (Jews and Christians) come after us on the Day of Resurrection. We are the last of (the Ummahs) among the people in this world and the first among the created to be judged on the Day of Resurrection. In one narration it is: ', to be judged among them}}
\hadithdefcmd{muslim}{1983}{حَدَّثَنَا أَبُو كُرَيْبٍ، أَخْبَرَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ سَعْدِ بْنِ طَارِقٍ، حَدَّثَنِي رِبْعِيُّ بْنُ، حِرَاشٍ عَنْ حُذَيْفَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هُدِينَا إِلَى الْجُمُعَةِ وَأَضَلَّ اللَّهُ عَنْهَا مَنْ كَانَ قَبْلَنَا ‏"‏ ‏.‏ فَذَكَرَ بِمَعْنَى حَدِيثِ ابْنِ فُضَيْلٍ ‏.‏\hadithno{1983}\hadithtrans{Huraira reported Allah's Messenger (ﷺ) as saying:We were guided aright to Friday (as a day of prayer and meditation), but Allah diverted those who were before us from it. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{1984}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، وَعَمْرُو بْنُ سَوَّادٍ الْعَامِرِيُّ، قَالَ أَبُو الطَّاهِرِ حَدَّثَنَا وَقَالَ الآخَرَانِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي أَبُو عَبْدِ اللَّهِ، الأَغَرُّ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا كَانَ يَوْمُ الْجُمُعَةِ كَانَ عَلَى كُلِّ بَابٍ مِنْ أَبْوَابِ الْمَسْجِدِ مَلاَئِكَةٌ يَكْتُبُونَ الأَوَّلَ فَالأَوَّلَ فَإِذَا جَلَسَ الإِمَامُ طَوَوُا الصُّحُفَ وَجَاءُوا يَسْتَمِعُونَ الذِّكْرَ وَمَثَلُ الْمُهَجِّرِ كَمَثَلِ الَّذِي يُهْدِي الْبَدَنَةَ ثُمَّ كَالَّذِي يُهْدِي بَقَرَةً ثُمَّ كَالَّذِي يُهْدِي الْكَبْشَ ثُمَّ كَالَّذِي يُهْدِي الدَّجَاجَةَ ثُمَّ كَالَّذِي يُهْدِي الْبَيْضَةَ»\hadithno{1984}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:When it is Friday, the angels stand at every door of the mosque and record the people in the order of their arrival, and when the Imam sits (on the pulpit for delivering the sermon) they fold up their sheets (manuscripts of the Qur'an) and listen to the mention (of Allah). And he who comes early is like one who offers a she-camel as a sacrifice, the next like one who offers a cow, the next a ram, the next a hen, the next an egg}}
\hadithdefcmd{muslim}{1985}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَعَمْرٌو النَّاقِدُ، عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{1985}\hadithtrans{This hadith has been narrated by Abu Huraira through another chain of transmitters}}
\hadithdefcmd{muslim}{1986}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ - عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ عَلَى كُلِّ بَابٍ مِنْ أَبْوَابِ الْمَسْجِدِ مَلَكٌ يَكْتُبُ الأَوَّلَ فَالأَوَّلَ - مَثَّلَ الْجَزُورَ ثُمَّ نَزَّلَهُمْ حَتَّى صَغَّرَ إِلَى مَثَلِ الْبَيْضَةِ - فَإِذَا جَلَسَ الإِمَامُ طُوِيَتِ الصُّحُفُ وَحَضَرُوا الذِّكْرَ ‏"‏ ‏\hadithno{1986}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There is an angel on every door of the mosque recording him first who (comes) first (to the mosque for Friday prayer). And he [the Prophet] likened him to one who offers a camel as a sacrifice and then he went on in the descending order till he reached the point at which the minimum (sacrifice) is that of an egg. And when the Imam sits (on the pulpit) the sheets are folded and they (the angels) attend to the mention of Allah}}
\hadithdefcmd{muslim}{1987}{حَدَّثَنَا أُمَيَّةُ بْنُ بِسْطَامٍ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - حَدَّثَنَا رَوْحٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اغْتَسَلَ ثُمَّ أَتَى الْجُمُعَةَ فَصَلَّى مَا قُدِّرَ لَهُ ثُمَّ أَنْصَتَ حَتَّى يَفْرُغَ مِنْ خُطْبَتِهِ ثُمَّ يُصَلِّيَ مَعَهُ غُفِرَ لَهُ مَا بَيْنَهُ وَبَيْنَ الْجُمُعَةِ الأُخْرَى وَفَضْلَ ثَلاَثَةِ أَيَّامٍ ‏"‏ ‏.‏\hadithno{1987}\hadithtrans{Abu-Huraira reported Allah's Apostle (ﷺ) as saying:He who took a bath and then came for Jumu'a prayer and then prayed what was fixed for him, then kept silence till the Imam finished the sermon, and then prayed along with him, his sins between that time and the next Friday would be forgiven, and even of three days more}}
\hadithdefcmd{muslim}{1988}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَأَبُو كُرَيْبٍ قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَوَضَّأَ فَأَحْسَنَ الْوُضُوءَ ثُمَّ أَتَى الْجُمُعَةَ فَاسْتَمَعَ وَأَنْصَتَ غُفِرَ لَهُ مَا بَيْنَهُ وَبَيْنَ الْجُمُعَةِ وَزِيَادَةُ ثَلاَثَةِ أَيَّامٍ وَمَنْ مَسَّ الْحَصَى فَقَدْ لَغَا ‏"‏ ‏.‏\hadithno{1988}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:He who performed ablution well, then came to Friday prayer, listened (to the sermon), kept silence all (his sins) between that time and the next Friday would be forgiven with three days extra, and he who touched pebbles caused an interruption}}
\hadithdefcmd{muslim}{1989}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَبُو بَكْرٍ حَدَّثَنَا يَحْيَى، بْنُ آدَمَ حَدَّثَنَا حَسَنُ بْنُ عَيَّاشٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنَّا نُصَلِّي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ نَرْجِعُ فَنُرِيحُ نَوَاضِحَنَا ‏.‏ قَالَ حَسَنٌ فَقُلْتُ لِجَعْفَرٍ فِي أَىِّ سَاعَةٍ تِلْكَ قَالَ زَوَالَ الشَّمْسِ ‏.‏\hadithno{1989}\hadithtrans{Jabir b. 'Abdullah reported:We used to observe (Jumu'a) prayer with the Messenger of Allah (ﷺ) and then we returned and gave rest to our camels used for carrying water. Hassan[ (one of the narrators) said: I asked Ja'far what time that was. He said.. It is the time when the sun passes the meridian}}
\hadithdefcmd{muslim}{1990}{وَحَدَّثَنِي الْقَاسِمُ بْنُ زَكَرِيَّاءَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، ح وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبْدِ، الرَّحْمَنِ الدَّارِمِيُّ حَدَّثَنَا يَحْيَى بْنُ حَسَّانَ، قَالاَ جَمِيعًا حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ جَعْفَرٍ، عَنْ أَبِيهِ، أَنَّهُ سَأَلَ جَابِرَ بْنَ عَبْدِ اللَّهِ مَتَى كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي الْجُمُعَةَ قَالَ كَانَ يُصَلِّي ثُمَّ نَذْهَبُ إِلَى جِمَالِنَا فَنُرِيحُهَا ‏.‏ زَادَ عَبْدُ اللَّهِ فِي حَدِيثِهِ حِينَ تَزُولُ الشَّمْسُ يَعْنِي النَّوَاضِحَ ‏.‏\hadithno{1990}\hadithtrans{Ja'far reported on the authority of his father:that he asked Jabir b. 'Abdullah when the Messenger of Allah (ﷺ) observed Jumu'a prayer. He said: He used to observe prayer, and we then went (back) to our camels and gave them rest. 'Abdullah made this addition in his narration: "Till the sun passed the meridian. and the camels used for carrying water (took rest)}}
\hadithdefcmd{muslim}{1991}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، وَيَحْيَى بْنُ يَحْيَى، وَعَلِيُّ بْنُ حُجْرٍ، قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ سَهْلٍ، قَالَ مَا كُنَّا نَقِيلُ وَلاَ نَتَغَدَّى إِلاَّ بَعْدَ الْجُمُعَةِ - زَادَ ابْنُ حُجْرٍ - فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1991}\hadithtrans{Sahl b. Said said:We did not have a siesta or lunch till after the Friday prayer. (Ibn Hajr added: ) "During the lifetime of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{1992}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالاَ أَخْبَرَنَا وَكِيعٌ، عَنْ يَعْلَى بْنِ، الْحَارِثِ الْمُحَارِبِيِّ عَنْ إِيَاسِ بْنِ سَلَمَةَ بْنِ الأَكْوَعِ، عَنْ أَبِيهِ، قَالَ كُنَّا نُجَمِّعُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذَا زَالَتِ الشَّمْسُ ثُمَّ نَرْجِعُ نَتَتَبَّعُ الْفَىْءَ ‏.‏\hadithno{1992}\hadithtrans{Iyas b. Salama b. al-Akwa' reported on the authority of his father:We used to observe the Friday prayer with the Messenger of Allah (ﷺ) when the sun passed the meridian. and we then returned and tried to find out afternoon shadow (of the walls for protecting themselves from the heat of the sun)}}
\hadithdefcmd{muslim}{1993}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا هِشَامُ بْنُ عَبْدِ الْمَلِكِ، حَدَّثَنَا يَعْلَى بْنُ الْحَارِثِ، عَنْ إِيَاسِ بْنِ سَلَمَةَ بْنِ الأَكْوَعِ، عَنْ أَبِيهِ، قَالَ كُنَّا نُصَلِّي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الْجُمُعَةَ فَنَرْجِعُ وَمَا نَجِدُ لِلْحِيطَانِ فَيْئًا نَسْتَظِلُّ بِهِ ‏.‏\hadithno{1993}\hadithtrans{Iyas b. Salama b. Akwa' reported on the authority of his father, saying:We used to observe the Friday prayer with the Messenger of Allah (ﷺ), and when we returned we did not find the shadow of the walls in which we could take protection (from the heat of the sun)}}
\hadithdefcmd{muslim}{1994}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، وَأَبُو كَامِلٍ الْجَحْدَرِيُّ جَمِيعًا عَنْ خَالِدٍ، - قَالَ أَبُو كَامِلٍ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، - حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَخْطُبُ يَوْمَ الْجُمُعَةِ قَائِمًا ثُمَّ يَجْلِسُ ثُمَّ يَقُومُ ‏.‏ قَالَ كَمَا يَفْعَلُونَ الْيَوْمَ ‏.‏\hadithno{1994}\hadithtrans{Ibn 'Umar said that the Messenger of Allah (ﷺ) used to deliver the sermon on Friday while standing. He would then sit and then stand (for the second sermon) as they (the Muslims) do nowadays}}
\hadithdefcmd{muslim}{1995}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَحَسَنُ بْنُ الرَّبِيعِ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كَانَتْ لِلنَّبِيِّ صلى الله عليه وسلم خُطْبَتَانِ يَجْلِسُ بَيْنَهُمَا يَقْرَأُ الْقُرْآنَ وَيُذَكِّرُ النَّاسَ ‏.‏\hadithno{1995}\hadithtrans{Jabir b. Samura said:The Apostle of Allah (ﷺ) gave two sermons between which he sat, recited the Qur'an and exhorted the people}}
\hadithdefcmd{muslim}{1996}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ سِمَاكٍ، قَالَ أَنْبَأَنِي جَابِرُ بْنُ، سَمُرَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَخْطُبُ قَائِمًا ثُمَّ يَجْلِسُ ثُمَّ يَقُومُ فَيَخْطُبُ قَائِمًا فَمَنْ نَبَّأَكَ أَنَّهُ كَانَ يَخْطُبُ جَالِسًا فَقَدْ كَذَبَ فَقَدْ وَاللَّهِ صَلَّيْتُ مَعَهُ أَكْثَرَ مِنْ أَلْفَىْ صَلاَةٍ\hadithno{1996}\hadithtrans{Jabir b. Samura said that the Messenger of Allah (ﷺ) used to deliver the sermon while standing. He would then sit down and then stand up and address in a standing posture; and whoever informed you that he (the Holy Prophet) delivered the sermon while sitting told a lie. By Allah. I prayed with him more than two thousand times}}
\hadithdefcmd{muslim}{1997}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، كِلاَهُمَا عَنْ جَرِيرٍ، - قَالَ عُثْمَانُ حَدَّثَنَا جَرِيرٌ، - عَنْ حُصَيْنِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ جَابِرِ، بْنِ عَبْدِ اللَّهِ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَخْطُبُ قَائِمًا يَوْمَ الْجُمُعَةِ فَجَاءَتْ عِيرٌ مِنَ الشَّامِ فَانْفَتَلَ النَّاسُ إِلَيْهَا حَتَّى لَمْ يَبْقَ إِلاَّ اثْنَا عَشَرَ رَجُلاً فَأُنْزِلَتْ هَذِهِ الآيَةُ الَّتِي فِي الْجُمُعَةِ ‏\{‏ وَإِذَا رَأَوْا تِجَارَةً أَوْ لَهْوًا انْفَضُّوا إِلَيْهَا وَتَرَكُوكَ قَائِمًا‏\}‏\hadithno{1997}\hadithtrans{Jabir b. Abdullah reported that the Apostle (ﷺ) was delivering the sermon on Friday in a standing posture when a caravan from Syria arrived. The people flocked towards it till no one was left (with the Holy Prophet) but twelve persons, and it was on this occasion that this verse in regard to Jumu'a was revealed." And when they see merchandise or sport. they break away to it and leave thee standing}}
\hadithdefcmd{muslim}{1998}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ حُصَيْنٍ، بِهَذَا الإِسْنَادِ قَالَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَخْطُبُ ‏.‏ وَلَمْ يَقُلْ قَائِمًا ‏.‏\hadithno{1998}\hadithtrans{This hadith has been narrated by Husain with the same chain of transmitters but with this alteration that he did not make mention of the standing position}}
\hadithdefcmd{muslim}{1999}{وَحَدَّثَنَا رِفَاعَةُ بْنُ الْهَيْثَمِ الْوَاسِطِيُّ، حَدَّثَنَا خَالِدٌ، - يَعْنِي الطَّحَّانَ - عَنْ حُصَيْنٍ، عَنْ سَالِمٍ، وَأَبِي، سُفْيَانَ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم يَوْمَ الْجُمُعَةِ فَقَدِمَتْ سُوَيْقَةٌ قَالَ فَخَرَجَ النَّاسُ إِلَيْهَا فَلَمْ يَبْقَ إِلاَّ اثْنَا عَشَرَ رَجُلاً أَنَا فِيهِمْ - قَالَ - فَأَنْزَلَ اللَّهُ ‏\{‏ وَإِذَا رَأَوْا تِجَارَةً أَوْ لَهْوًا انْفَضُّوا إِلَيْهَا وَتَرَكُوكَ قَائِمًا‏\}‏ إِلَى آخِرِ الآيَةِ ‏.‏\hadithno{1999}\hadithtrans{Jabir b. Abdullah reported:I was along with the Messenger of Allah (ﷺ) on Friday when a caravan arrived. The people went to it, and none but twelve persons were left behind and I was one of them; and it was on this occasion that this verse was revealed:" And when they see merchandise or sport away to it, and leave thee standing" (lxii. 1 1). they break}}
\hadithdefcmd{muslim}{2000}{وَحَدَّثَنَا إِسْمَاعِيلُ بْنُ سَالِمٍ، أَخْبَرَنَا هُشَيْمٌ، أَخْبَرَنَا حُصَيْنٌ، عَنْ أَبِي سُفْيَانَ، وَسَالِمِ، بْنِ أَبِي الْجَعْدِ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ بَيْنَا النَّبِيُّ صلى الله عليه وسلم قَائِمٌ يَوْمَ الْجُمُعَةِ إِذْ قَدِمَتْ عِيرٌ إِلَى الْمَدِينَةِ فَابْتَدَرَهَا أَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى لَمْ يَبْقَ مَعَهُ إِلاَّ اثْنَا عَشَرَ رَجُلاً فِيهِمْ أَبُو بَكْرٍ وَعُمَرُ - قَالَ - وَنَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ وَإِذَا رَأَوْا تِجَارَةً أَوْ لَهْوًا انْفَضُّوا إِلَيْهَا‏\}‏\hadithno{2000}\hadithtrans{Jabir b. Abdullah reported:While the Messenger of Allah (ﷺ) was delivering (a sermon) on Friday, a caravan of merchandise came to Medina. The Companions of the Messenger of Allah (ﷺ) rushed towards it till only twelve persons were left with him including Abu Bakr and 'Umar; and it was at this occasion that this verse was revealed." And when they see merchandise or sport, they break away to it}}
\hadithdefcmd{muslim}{2001}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي عُبَيْدَةَ، عَنْ كَعْبِ بْنِ عُجْرَةَ، قَالَ دَخَلَ الْمَسْجِدَ وَعَبْدُ الرَّحْمَنِ بْنُ أُمِّ الْحَكَمِ يَخْطُبُ قَاعِدًا فَقَالَ انْظُرُوا إِلَى هَذَا الْخَبِيثِ يَخْطُبُ قَاعِدًا وَقَالَ اللَّهُ تَعَالَى ‏\{‏ وَإِذَا رَأَوْا تِجَارَةً أَوْ لَهْوًا انْفَضُّوا إِلَيْهَا وَتَرَكُوكَ قَائِمًا‏\}‏\hadithno{2001}\hadithtrans{Ka'b b. 'Ujra reported that he entered the mosque and saw Abd al-Rahman b. Umm Hakam delivering the sermon in a sitting posture. Upon this he said:Look at this wretched person; he delivers the sermon while sitting, whereas Allah said:" And when they see merchandise or sport, they break away to it and leave thee standing}}
\hadithdefcmd{muslim}{2002}{وَحَدَّثَنِي الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، حَدَّثَنَا أَبُو تَوْبَةَ، حَدَّثَنَا مُعَاوِيَةُ، - وَهُوَ ابْنُ سَلاَّمٍ - عَنْ زَيْدٍ، - يَعْنِي أَخَاهُ - أَنَّهُ سَمِعَ أَبَا سَلاَّمٍ، قَالَ حَدَّثَنِي الْحَكَمُ بْنُ مِينَاءَ، أَنَّحَدَّثَاهُ أَنَّهُمَا، سَمِعَا رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ عَلَى أَعْوَادِ مِنْبَرِهِ ‏ "‏ لَيَنْتَهِيَنَّ أَقْوَامٌ عَنْ وَدْعِهِمُ الْجُمُعَاتِ أَوْ لَيَخْتِمَنَّ اللَّهُ عَلَى قُلُوبِهِمْ ثُمَّ لَيَكُونُنَّ مِنَ الْغَافِلِينَ ‏"‏ ‏.‏\hadithno{2002}\hadithtrans{Abdullah b. Umar and Abu Huraira said that they heard Allah's Messenger (ﷺ) say on the planks of his pulpit:People must cease to neglect the Friday prayer or Allah will seal their hearts and then they will be among the negligent}}
\hadithdefcmd{muslim}{2003}{حَدَّثَنَا حَسَنُ بْنُ الرَّبِيعِ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ قَالاَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كُنْتُ أُصَلِّي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَكَانَتْ صَلاَتُهُ قَصْدًا وَخُطْبَتُهُ قَصْدًا ‏.‏\hadithno{2003}\hadithtrans{Jabir b. Samura reported:I used to pray with the Messenger of Allah (ﷺ) and both his prayer and sermon were of moderate length}}
\hadithdefcmd{muslim}{2004}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا زَكَرِيَّاءُ، حَدَّثَنِي سِمَاكُ بْنُ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كُنْتُ أُصَلِّي مَعَ النَّبِيِّ صلى الله عليه وسلم الصَّلَوَاتِ فَكَانَتْ صَلاَتُهُ قَصْدًا وَخُطْبَتُهُ قَصْدًا ‏.‏ وَفِي رِوَايَةِ أَبِي بَكْرٍ زَكَرِيَّاءُ عَنْ سِمَاكٍ\hadithno{2004}\hadithtrans{Jabir b. Samura reported:I used to observe prayer with the Messenger of Allah (ﷺ) and his prayer was of moderate length and his sermon too was of moderate length}}
\hadithdefcmd{muslim}{2005}{وَحَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَبْدِ الْمَجِيدِ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا خَطَبَ احْمَرَّتْ عَيْنَاهُ وَعَلاَ صَوْتُهُ وَاشْتَدَّ غَضَبُهُ حَتَّى كَأَنَّهُ مُنْذِرُ جَيْشٍ يَقُولُ ‏"‏ صَبَّحَكُمْ وَمَسَّاكُمْ ‏"‏ ‏.‏ وَيَقُولُ ‏"‏ بُعِثْتُ أَنَا وَالسَّاعَةَ كَهَاتَيْنِ ‏"‏ ‏.‏ وَيَقْرُنُ بَيْنَ إِصْبَعَيْهِ السَّبَّابَةِ وَالْوُسْطَى وَيَقُولُ ‏"‏ أَمَّا بَعْدُ فَإِنَّ خَيْرَ الْحَدِيثِ كِتَابُ اللَّهِ وَخَيْرُ الْهُدَى هُدَى مُحَمَّدٍ وَشَرُّ الأُمُورِ مُحْدَثَاتُهَا وَكُلُّ بِدْعَةٍ ضَلاَلَةٌ ‏"‏ ‏.‏ ثُمَّ يَقُولُ ‏"‏ أَنَا أَوْلَى بِكُلِّ مُؤْمِنٍ مِنْ نَفْسِهِ مَنْ تَرَكَ مَالاً فَلأَهْلِهِ وَمَنْ تَرَكَ دَيْنًا أَوْ ضَيَاعًا فَإِلَىَّ وَعَلَىَّ ‏"‏ ‏.‏\hadithno{2005}\hadithtrans{Jabir b. Abdullah said:When Allah's Messenger (may peace he upon him) delivered the sermon, his eyes became red, his voice rose, and his anger increased so that he was like one giving a warning against the enemy and saying: "The enemy has made a morning attack on you and in the evening too." He would also say: "The Last Hour and I have been sent like these two." And he would join his forefinger and middle finger; and would further say: "The best of the speech is embodied in the Book of Allah, and the best of the guidance is the guidance given by Muhammad. And the most evil affairs are their innovations; and every innovation is error." He would further say:, I am more dear to a Muslim even than his self; and he who left behind property that is for his family; and he who dies under debt or leaves children (in helplessness), the responsibility (of paying his debt and bringing up his children) lies on me}}
\hadithdefcmd{muslim}{2006}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، حَدَّثَنِي جَعْفَرُ، بْنُ مُحَمَّدٍ عَنْ أَبِيهِ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ كَانَتْ خُطْبَةُ النَّبِيِّ صلى الله عليه وسلم يَوْمَ الْجُمُعَةِ يَحْمَدُ اللَّهَ وَيُثْنِي عَلَيْهِ ثُمَّ يَقُولُ عَلَى إِثْرِ ذَلِكَ وَقَدْ عَلاَ صَوْتُهُ ‏.‏ ثُمَّ سَاقَ الْحَدِيثَ بِمِثْلِهِ ‏.‏\hadithno{2006}\hadithtrans{Ja'far b. Muhammad said on the authority of his father:I heard Jabir b. 'Abdullah saying that in the sermon of the Messenger of Allah (ﷺ) he praised Allah, lauded Him (and subsequently said [other words] and raised his voice, and the rest of the hadith is the same}}
\hadithdefcmd{muslim}{2007}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ جَعْفَرٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَخْطُبُ النَّاسَ يَحْمَدُ اللَّهَ وَيُثْنِي عَلَيْهِ بِمَا هُوَ أَهْلُهُ ثُمَّ يَقُولُ ‏ "‏ مَنْ يَهْدِهِ اللَّهُ فَلاَ مُضِلَّ لَهُ وَمَنْ يُضْلِلْ فَلاَ هَادِيَ لَهُ وَخَيْرُ الْحَدِيثِ كِتَابُ اللَّهِ ‏"‏ ‏.‏ ثُمَّ سَاقَ الْحَدِيثَ بِمِثْلِ حَدِيثِ الثَّقَفِيِّ ‏.‏\hadithno{2007}\hadithtrans{Jabir reported that the Messenger of Allah (ﷺ), while delivering the sermon' to the people, praised Allah, and lauded Him for what He deserves, and would then say:He whom Allah guides aright, there is none to mislead him, and he who is led astray, there is none to guide him (aright), and the best of the talk is embodied in the Book of Allah. And the rest of the hadith is the same}}
\hadithdefcmd{muslim}{2008}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، كِلاَهُمَا عَنْ عَبْدِ الأَعْلَى، - قَالَ ابْنُ الْمُثَنَّى حَدَّثَنِي عَبْدُ الأَعْلَى، وَهُوَ أَبُو هَمَّامٍ - حَدَّثَنَا دَاوُدُ، عَنْ عَمْرِو بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ ضِمَادًا، قَدِمَ مَكَّةَ وَكَانَ مِنْ أَزْدِ شَنُوءَةَ وَكَانَ يَرْقِي مِنْ هَذِهِ الرِّيحِ فَسَمِعَ سُفَهَاءَ مِنْ أَهْلِ مَكَّةَ يَقُولُونَ إِنَّ مُحَمَّدًا مَجْنُونٌ ‏.‏ فَقَالَ لَوْ أَنِّي رَأَيْتُ هَذَا الرَّجُلَ لَعَلَّ اللَّهَ يَشْفِيهِ عَلَى يَدَىَّ - قَالَ - فَلَقِيَهُ فَقَالَ يَا مُحَمَّدُ إِنِّي أَرْقِي مِنْ هَذِهِ الرِّيحِ وَإِنَّ اللَّهَ يَشْفِي عَلَى يَدِي مَنْ شَاءَ فَهَلْ لَكَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الْحَمْدَ لِلَّهِ نَحْمَدُهُ وَنَسْتَعِينُهُ مَنْ يَهْدِهِ اللَّهُ فَلاَ مُضِلَّ لَهُ وَمَنْ يُضْلِلْ فَلاَ هَادِيَ لَهُ وَأَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ وَأَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ أَمَّا بَعْدُ ‏"‏ ‏.‏ قَالَ فَقَالَ أَعِدْ عَلَىَّ كَلِمَاتِكَ هَؤُلاَءِ ‏.‏ فَأَعَادَهُنَّ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم ثَلاَثَ مَرَّاتٍ - قَالَ - فَقَالَ لَقَدْ سَمِعْتُ قَوْلَ الْكَهَنَةِ وَقَوْلَ السَّحَرَةِ وَقَوْلَ الشُّعَرَاءِ فَمَا سَمِعْتُ مِثْلَ كَلِمَاتِكَ هَؤُلاَءِ وَلَقَدْ بَلَغْنَ نَاعُوسَ الْبَحْرِ - قَالَ - فَقَالَ هَاتِ يَدَكَ أُبَايِعْكَ عَلَى الإِسْلاَمِ - قَالَ - فَبَايَعَهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَعَلَى قَوْمِكَ ‏"‏ ‏.‏ قَالَ وَعَلَى قَوْمِي - قَالَ - فَبَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَرِيَّةً فَمَرُّوا بِقَوْمِهِ فَقَالَ صَاحِبُ السَّرِيَّةِ لِلْجَيْشِ هَلْ أَصَبْتُمْ مِنْ هَؤُلاَءِ شَيْئًا فَقَالَ رَجُلٌ مِنَ الْقَوْمِ أَصَبْتُ مِنْهُمْ مِطْهَرَةً ‏.‏ فَقَالَ رُدُّوهَا فَإِنَّ هَؤُلاَءِ قَوْمُ ضِمَادٍ ‏.‏\hadithno{2008}\hadithtrans{Ibn 'Abbas reported:Dimad came to Mecca and he belonged to the tribe of Azd Shanu'a, and he used to protect the person who was under the influence of charm. He heard the foolish people of Mecca say that Muhammad (ﷺ) was under the spell. Upon this he said: If 1 were to come across this man, Allah might cure him at my hand. He met him and said: Muhammad, I can protect (one) who is under the influence of charm, and Allah cures one whom He so desires at my hand. Do you desire (this)? Upon this the Messenger of Allah (ﷺ) said: Praise is due to Allah, we praise Him, ask His help; and he whom Allah guides aright there is none to lead him astray, and he who is led astray there is none to guide him, and I bear testimony to the fact that there is no god but Allah, He is One, having no partner with Him, and that Muhammad is His Servant and Messenger. Now after this he (Dimad) said: Repeat these words of yours before me, and the messenger of Allah (ﷺ) repeated these to him thrice; and he said I have heard the words of soothsayers and the words of magicians, and the words of poets, but I have never heard such words as yours, and they reach the depth (of the ocean of eloquence) ; bring forth your hand so that I should take oath of fealty to you on Islam. So he took an oath of allegiance to him. The Messenger of Allah (ﷺ) said: It (this allegiance of yours) is on behalf of your people too. He said: It is on behalf of my people too. The Messenger of Allah (ﷺ) sent an expedition and the flying column passed by his people. The leader of the flying column said to the detachment: Did you find anything from these people? One of the people said: I found a utensil for water. Upon this he (the commander) said: Return it, for he is one of the people of Dimad}}
\hadithdefcmd{muslim}{2009}{حَدَّثَنِي سُرَيْجُ بْنُ يُونُسَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبْجَرَ، عَنْ أَبِيهِ، عَنْ وَاصِلِ بْنِ حَيَّانَ، قَالَ قَالَ أَبُو وَائِلٍ خَطَبَنَا عَمَّارٌ فَأَوْجَزَ وَأَبْلَغَ فَلَمَّا نَزَلَ قُلْنَا يَا أَبَا الْيَقْظَانِ لَقَدْ أَبْلَغْتَ وَأَوْجَزْتَ فَلَوْ كُنْتَ تَنَفَّسْتَ ‏.‏ فَقَالَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ طُولَ صَلاَةِ الرَّجُلِ وَقِصَرَ خُطْبَتِهِ مَئِنَّةٌ مِنْ فِقْهِهِ فَأَطِيلُوا الصَّلاَةَ وَاقْصُرُوا الْخُطْبَةَ وَإِنَّ مِنَ الْبَيَانِ سِحْرًا ‏"‏ ‏.‏\hadithno{2009}\hadithtrans{Abu Wa'il reported:'Ammar delivered to us the sermon. It was short and eloquent. When he (, Ammir) descended (from the pulpit) we said to him: 0 Abd al-Yaqzn, you have delivered a short and eloquent sermon. Would that you had lengthened (the sermon). He said: I have heard the Messenger of Allah (ﷺ) as saying: The lengthening of prayer by a man and the shortness of the sermon is the sign of his understanding (of faith). So lengthen the prayer and shorten the sermon, for there is charm (in precise) expression}}
\hadithdefcmd{muslim}{2010}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، عَنْ تَمِيمِ بْنِ طَرَفَةَ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، أَنَّ رَجُلاً، خَطَبَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ مَنْ يُطِعِ اللَّهَ وَرَسُولَهُ فَقَدْ رَشِدَ وَمَنْ يَعْصِهِمَا فَقَدْ غَوَى ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بِئْسَ الْخَطِيبُ أَنْتَ ‏.‏ قُلْ وَمَنْ يَعْصِ اللَّهَ وَرَسُولَهُ ‏"‏ ‏.‏ قَالَ ابْنُ نُمَيْرٍ فَقَدْ غَوِيَ ‏.‏\hadithno{2010}\hadithtrans{Adi b. Hatim reported:that a person recited a sermon before the Messenger of Allah (ﷺ) thus: He who obeys Allah and His Apostle, he in fact follows the right path, and he who disobeys both of them, he goes astray. Upon this the Messenger of Allah (ﷺ) said: What a bad speaker you are; say: He who disobeys Allah and His Apostle. Ibn Numair added: He in fact went astray}}
\hadithdefcmd{muslim}{2011}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَإِسْحَاقُ الْحَنْظَلِيُّ جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، - قَالَ قُتَيْبَةُ حَدَّثَنَا سُفْيَانُ، - عَنْ عَمْرٍو، سَمِعَ عَطَاءً، يُخْبِرُ عَنْ صَفْوَانَ بْنِ، يَعْلَى عَنْ أَبِيهِ، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقْرَأُ عَلَى الْمِنْبَرِ ‏\{‏ وَنَادَوْا يَا مَالِكُ‏\}‏\hadithno{2011}\hadithtrans{Safwan b. Ya'la reported on the authority of his father that he heard the Messenger of Allah (ﷺ) reciting (verses of the Qur'an) on the pulpit. and" They cried:0 Malik}}
\hadithdefcmd{muslim}{2012}{وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا يَحْيَى بْنُ حَسَّانَ، حَدَّثَنَا سُلَيْمَانُ، بْنُ بِلاَلٍ عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ أُخْتٍ، لِعَمْرَةَ قَالَتْ أَخَذْتُ ‏\{‏ ق وَالْقُرْآنِ الْمَجِيدِ‏\}‏ مِنْ فِي رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ الْجُمُعَةِ وَهُوَ يَقْرَأُ بِهَا عَلَى الْمِنْبَرِ فِي كُلِّ جُمُعَةٍ ‏.‏\hadithno{2012}\hadithtrans{Amra daughter of Abd al-Rahman reported on the authority of the sister of Amra:I memorised (surah) "Qaf, by the glorious Qur'an" from the mouth of the Messenger of Allah (ﷺ) on Friday for he recited it on the pulpit on every Friday}}
\hadithdefcmd{muslim}{2013}{وَحَدَّثَنِيهِ أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ يَحْيَى بْنِ أَيُّوبَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ أُخْتٍ، لِعَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ كَانَتْ أَكْبَرَ مِنْهَا ‏.‏ بِمِثْلِ حَدِيثِ سُلَيْمَانَ بْنِ بِلاَلٍ ‏.‏\hadithno{2013}\hadithtrans{The daughter of Haritha b. Nu'man said:I did not memorise (Surah) Qaf but from the mouth of the Messenger of Allah (ﷺ) as he used to deliver the. sermon along with it on every Friday. She also added: Our oven and that of the Messenger of Allah (ﷺ) was one}}
\hadithdefcmd{muslim}{2014}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ خُبَيْبٍ، عَنْ عَبْدِ، اللَّهِ بْنِ مُحَمَّدِ بْنِ مَعْنٍ عَنْ بِنْتٍ لِحَارِثَةَ بْنِ النُّعْمَانِ، قَالَتْ مَا حَفِظْتُ ‏\{‏ ق‏\}‏ إِلاَّ مِنْ فِي رَسُولِ اللَّهِ صلى الله عليه وسلم يَخْطُبُ بِهَا كُلَّ جُمُعَةٍ ‏.‏ قَالَتْ وَكَانَ تَنُّورُنَا وَتَنُّورُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَاحِدًا ‏.‏\hadithno{2014}\hadithtrans{Umm Bisham hint Haritha b. Nu'man said:Our oven and that of the Messenger of Allah (ﷺ) was one for two years, or for one year or for a part of a year; and I learnt" Qaf. By the Glorious Qur'an" from no other source than the tongue of Allah's Messenger (ﷺ) who used to recite it every Friday on the pulpit when he delivered the sermon to the people}}
\hadithdefcmd{muslim}{2015}{وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ مُحَمَّدِ، بْنِ إِسْحَاقَ قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ الأَنْصَارِيُّ، عَنْ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ سَعْدِ بْنِ زُرَارَةَ، عَنْ أُمِّ هِشَامٍ بِنْتِ حَارِثَةَ بْنِ النُّعْمَانِ، قَالَتْ لَقَدْ كَانَ تَنُّورُنَا وَتَنُّورُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَاحِدًا سَنَتَيْنِ أَوْ سَنَةً وَبَعْضَ سَنَةٍ وَمَا أَخَذْتُ ‏\{‏ ق وَالْقُرْآنِ الْمَجِيدِ‏\}‏ إِلاَّ عَنْ لِسَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَقْرَؤُهَا كُلَّ يَوْمِ جُمُعَةٍ عَلَى الْمِنْبَرِ إِذَا خَطَبَ النَّاسَ ‏.‏\hadithno{2015}\hadithtrans{It was narrated that Umm Hisham bin Harithah bin An-Nu'man said:"Our oven and the oven of the Messenger of Allah (ﷺ) were the same for two years, or for one year and part of a year. And I only learned "Surah Qaf. By the Glorious Quran" from the tongue of the Messenger of Allah (ﷺ), who used to recited it every Friday from the Minbar, when he addresses the people}}
\hadithdefcmd{muslim}{2016}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ حُصَيْنٍ، عَنْ عُمَارَةَ، بْنِ رُؤَيْبَةَ قَالَ رَأَى بِشْرَ بْنَ مَرْوَانَ عَلَى الْمِنْبَرِ رَافِعًا يَدَيْهِ فَقَالَ قَبَّحَ اللَّهُ هَاتَيْنِ الْيَدَيْنِ لَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم مَا يَزِيدُ عَلَى أَنْ يَقُولَ بِيَدِهِ هَكَذَا ‏.‏ وَأَشَارَ بِإِصْبَعِهِ الْمُسَبِّحَةِ ‏.‏\hadithno{2016}\hadithtrans{Umara b. Ruwaiba said he saw Bishr b. Marwan on the pulpit raising his hands and said:Allah, disfigure these hands! I have seen Allah's Messenger (ﷺ) gesture no more than this with his hands, and he pointed with his forefinger}}
\hadithdefcmd{muslim}{2017}{وَحَدَّثَنَاهُ قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ حُصَيْنِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ رَأَيْتُ بِشْرَ بْنَ مَرْوَانَ يَوْمَ جُمُعَةٍ يَرْفَعُ يَدَيْهِ ‏.‏ فَقَالَ عُمَارَةُ بْنُ رُؤَيْبَةَ ‏.‏ فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{2017}\hadithtrans{This hadith has been narrated by another chain of transmitters on the authority of Husain b. Abd al-Rahman}}
\hadithdefcmd{muslim}{2018}{وَحَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا حَمَّادٌ، - وَ هُوَ ابْنُ زَيْدٍ - عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ بَيْنَا النَّبِيُّ صلى الله عليه وسلم يَخْطُبُ يَوْمَ الْجُمُعَةِ إِذْ جَاءَ رَجُلٌ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَصَلَّيْتَ يَا فُلاَنُ "‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ قُمْ فَارْكَعْ ‏"‏ ‏.‏\hadithno{2018}\hadithtrans{Jabir b. 'Abdullah reported that while Allah's Messenger (ﷺ) was delivering the sermon on Friday a person came there, and the Messenger of Allah (ﷺ) said to him:So and so, have you prayed (two rak'ahs)? He said: No. He (the Holy Prophet) said: Then stand and pray}}
\hadithdefcmd{muslim}{2019}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَيَعْقُوبُ الدَّوْرَقِيُّ، عَنِ ابْنِ عُلَيَّةَ، عَنْ أَيُّوبَ، عَنْ عَمْرٍو، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم كَمَا قَالَ حَمَّادٌ وَلَمْ يَذْكُرِ الرَّكْعَتَيْنِ ‏.‏\hadithno{2019}\hadithtrans{This hadith is narrated by Jabir through another chain of transmitters but Hammad (one of the narrators) made no mention of the two rak'ahs}}
\hadithdefcmd{muslim}{2020}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ قُتَيْبَةُ حَدَّثَنَا وَقَالَ، إِسْحَاقُ أَخْبَرَنَا سُفْيَانُ، عَنْ عَمْرٍو، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ دَخَلَ رَجُلٌ الْمَسْجِدَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَخْطُبُ يَوْمَ الْجُمُعَةِ فَقَالَ ‏"‏ أَصَلَّيْتَ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ قُمْ فَصَلِّ الرَّكْعَتَيْنِ ‏"‏ ‏.‏ وَفِي رِوَايَةِ قُتَيْبَةَ قَالَ ‏"‏ صَلِّ رَكْعَتَيْنِ ‏"‏ ‏.‏\hadithno{2020}\hadithtrans{Jabir b. 'Abdullah said that a person entered the Mosque while the Messenger of Allah (ﷺ) was delivering the sermon on Friday. Upon this he (the Holy Prophet) said:Have you observed prayer? He said: No. He (the Holy Prophet) said: Stand and offer the two rak'ahs. According to Qutaiba, the words are:" He said: Offer two rak'ahs}}
\hadithdefcmd{muslim}{2021}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ ابْنُ رَافِعٍ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ جَاءَ رَجُلٌ وَالنَّبِيُّ صلى الله عليه وسلم عَلَى الْمِنْبَرِ يَوْمَ الْجُمُعَةِ يَخْطُبُ فَقَالَ لَهُ ‏ "‏ أَرَكَعْتَ رَكْعَتَيْنِ ‏"‏ ‏.‏ قَالَ لاَ. فَقَالَ: «ارْكَعْ»\hadithno{2021}\hadithtrans{Jabir b. 'Abdullah reported that a person came (in the Mosque) while the Messenger of Allah (ﷺ) was delivering the sermon on Friday (standing) on the pulpit. He (the Holy Prophet) said to him:Have you offered two rak'ahs? He said: No. Upon this he said: Then observe (them)}}
\hadithdefcmd{muslim}{2022}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدٌ، - وَهُوَ ابْنُ جَعْفَرٍ - حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرٍو، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَطَبَ فَقَالَ ‏ "‏ إِذَا جَاءَ أَحَدُكُمْ يَوْمَ الْجُمُعَةِ وَقَدْ خَرَجَ الإِمَامُ فَلْيُصَلِّ رَكْعَتَيْنِ ‏"‏ ‏.‏\hadithno{2022}\hadithtrans{Jabir b. 'Abdullah said that the Messenger of Allah (ﷺ) delivered the sermon and said:When any one of you comes for the Friday (prayer) and the Imam comes out (from his apartment), (even then) should observe two rak'ahs (of prayer)}}
\hadithdefcmd{muslim}{2023}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّهُ قَالَ جَاءَ سُلَيْكٌ الْغَطَفَانِيُّ يَوْمَ الْجُمُعَةِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم قَاعِدٌ عَلَى الْمِنْبَرِ فَقَعَدَ سُلَيْكٌ قَبْلَ أَنْ يُصَلِّيَ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَرَكَعْتَ رَكْعَتَيْنِ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ قُمْ فَارْكَعْهُمَا ‏"‏ ‏.‏\hadithno{2023}\hadithtrans{Jabir reported that Sulaik Ghatafani came on Friday (for prayer) while the Messenger of Allah (ﷺ) was sitting on the pulpit. Sulaik also sat down before observing prayer. The Apostle of Allah (ﷺ) said:Have you observed two rak'ahs? He said: No. He (the Holy Prophet) said: Stand and observe them}}
\hadithdefcmd{muslim}{2024}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَلِيُّ بْنُ خَشْرَمٍ، كِلاَهُمَا عَنْ عِيسَى بْنِ يُونُسَ، - قَالَ ابْنُ خَشْرَمٍ أَخْبَرَنَا عِيسَى، - عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ جَاءَ سُلَيْكٌ الْغَطَفَانِيُّ يَوْمَ الْجُمُعَةِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَخْطُبُ فَجَلَسَ فَقَالَ لَهُ ‏ "‏ يَا سُلَيْكُ قُمْ فَارْكَعْ رَكْعَتَيْنِ وَتَجَوَّزْ فِيهِمَا - ثُمَّ قَالَ - إِذَا جَاءَ أَحَدُكُمْ يَوْمَ الْجُمُعَةِ وَالإِمَامُ يَخْطُبُ فَلْيَرْكَعْ رَكْعَتَيْنِ وَلْيَتَجَوَّزْ فِيهِمَا ‏"‏ ‏.‏\hadithno{2024}\hadithtrans{Jabir b. 'Abdullah reported:Sulaik Ghatafani came on Friday when the Messenger of Allah (ﷺ) was delivering the sermon. He (Sulaik) sat down. He (the Holy Prophet) said to him: 0 Sulaik I stand and observe two rak'ahs and make them short, and then said: When any one of you comes on Friday, while the Imam delivers the sermon, he should observe two rak'ahs and should make them short}}
\hadithdefcmd{muslim}{2025}{وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، حَدَّثَنَا حُمَيْدُ بْنُ هِلاَلٍ، قَالَ قَالَ أَبُو رِفَاعَةَ انْتَهَيْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ يَخْطُبُ قَالَ فَقُلْتُ يَا رَسُولَ اللَّهِ رَجُلٌ غَرِيبٌ جَاءَ يَسْأَلُ عَنْ دِينِهِ لاَ يَدْرِي مَا دِينُهُ - قَالَ - فَأَقْبَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَتَرَكَ خُطْبَتَهُ حَتَّى انْتَهَى إِلَىَّ فَأُتِيَ بِكُرْسِيٍّ حَسِبْتُ قَوَائِمَهُ حَدِيدًا - قَالَ - فَقَعَدَ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَجَعَلَ يُعَلِّمُنِي مِمَّا عَلَّمَهُ اللَّهُ ثُمَّ أَتَى خُطْبَتَهُ فَأَتَمَّ آخِرَهَا ‏.‏\hadithno{2025}\hadithtrans{Abu Rifa'a reported:I came to the Prophet (ﷺ) when he was delivering the sermon, and I said: Messenger of Allah, here is a stranger and he wants to learn about this religion and he does not know what this religion is. The Messenger of Allah (ﷺ) looked at me and left his sermon till he came to me, and he was given a chair and I thought that Its legs were made of iron. The Messenger of Allah (ﷺ) sat In it and he began to teach me what Allah had taught him. He then came (to the pulpit) for his sermon and completed it to the end}}
\hadithdefcmd{muslim}{2026}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا سُلَيْمَانُ، - وَهُوَ ابْنُ بِلاَلٍ - عَنْ جَعْفَرٍ، عَنْ أَبِيهِ، عَنِ ابْنِ أَبِي رَافِعٍ، قَالَ اسْتَخْلَفَ مَرْوَانُ أَبَا هُرَيْرَةَ عَلَى الْمَدِينَةِ وَخَرَجَ إِلَى مَكَّةَ فَصَلَّى لَنَا أَبُو هُرَيْرَةَ الْجُمُعَةَ فَقَرَأَ بَعْدَ سُورَةِ الْجُمُعَةِ فِي الرَّكْعَةِ الآخِرَةِ ‏\{‏ إِذَا جَاءَكَ الْمُنَافِقُونَ‏\}‏ - قَالَ - فَأَدْرَكْتُ أَبَا هُرَيْرَةَ حِينَ انْصَرَفَ فَقُلْتُ لَهُ إِنَّكَ قَرَأْتَ بِسُورَتَيْنِ كَانَ عَلِيُّ بْنُ أَبِي طَالِبٍ يَقْرَأُ بِهِمَا بِالْكُوفَةِ ‏.‏ فَقَالَ أَبُو هُرَيْرَةَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقْرَأُ بِهِمَا يَوْمَ الْجُمُعَةِ ‏.‏\hadithno{2026}\hadithtrans{Ibn Abu Rafi' said:Marwan appointed Abu Huraira as his deputy in Medina and he himself left for Mecca. Abu Huraira led us in the Jumu'a prayer and recited after Surah Jumu'a in the second rak'ah:" When the hypocrites came to thee" (Surah 63). I then met Abu Huraira as he came back and said to him: You have recited two surahs which 'Ali b. Abu Talib used to recite in Kufah. Upon this Abu Huraira said: I heard the Messenger of Allah (ﷺ) reciting these two in the Friday (prayer)}}
\hadithdefcmd{muslim}{2027}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ قَالاَ حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، ح وَحَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي الدَّرَاوَرْدِيَّ - كِلاَهُمَا عَنْ جَعْفَرٍ، عَنْ أَبِيهِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، قَالَ اسْتَخْلَفَ مَرْوَانُ أَبَا هُرَيْرَةَ ‏.‏ بِمِثْلِهِ غَيْرَ أَنَّ فِي، رِوَايَةِ حَاتِمٍ فَقَرَأَ بِسُورَةِ الْجُمُعَةِ فِي السَّجْدَةِ الأُولَى وَفِي الآخِرَةِ ‏\{‏ إِذَا جَاءَكَ الْمُنَافِقُونَ‏\}‏ وَرِوَايَةُ عَبْدِ الْعَزِيزِ مِثْلُ حَدِيثِ سُلَيْمَانَ بْنِ بِلاَلٍ ‏.‏\hadithno{2027}\hadithtrans{This hadith is narrated by Abdullah b. Abu Rafi' with the same chain of transmitters but with this modification:" That he recited Surah Jumu'a (lxii.) in the first rak'ah and" The hypocrites came" in the second rak'ah}}
\hadithdefcmd{muslim}{2028}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَإِسْحَاقُ جَمِيعًا عَنْ جَرِيرٍ، - قَالَ يَحْيَى أَخْبَرَنَا جَرِيرٌ، - عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ الْمُنْتَشِرِ، عَنْ أَبِيهِ، عَنْ حَبِيبِ بْنِ، سَالِمٍ مَوْلَى النُّعْمَانِ بْنِ بَشِيرٍ عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرَأُ فِي الْعِيدَيْنِ وَفِي الْجُمُعَةِ بِـ ‏\{‏ سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى‏\}‏ وَ ‏\{‏ هَلْ أَتَاكَ حَدِيثُ الْغَاشِيَةِ‏\}‏ قَالَ وَإِذَا اجْتَمَعَ الْعِيدُ وَالْجُمُعَةُ فِي يَوْمٍ وَاحِدٍ يَقْرَأُ بِهِمَا أَيْضًا فِي الصَّلاَتَيْنِ\hadithno{2028}\hadithtrans{Nu'man b. Bashir reported that the Messenger of Allah (ﷺ) used to recite on two 'Ids and in Friday prayer:" Glorify The name of Thy Lord, the Most High" (Surah lxxxvii.), and:" Has there come to thee the news of the overwhelming event" (lxxxviii.). And when the 'Id and Jumu'a combined on a day he recited these two (surah) in both the prayers}}
\hadithdefcmd{muslim}{2029}{وَحَدَّثَنَاهُ قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ الْمُنْتَشِرِ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{2029}\hadithtrans{This hadith has been narrated by Ibrahim b Muhammad b. al-Muntashir with the same chain of transmitters}}
\hadithdefcmd{muslim}{2030}{وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ ضَمْرَةَ بْنِ سَعِيدٍ، عَنْ عُبَيْدِ، اللَّهِ بْنِ عَبْدِ اللَّهِ قَالَ كَتَبَ الضَّحَّاكُ بْنُ قَيْسٍ إِلَى النُّعْمَانِ بْنِ بَشِيرٍ يَسْأَلُهُ أَىَّ شَىْءٍ قَرَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ الْجُمُعَةِ سِوَى سُورَةِ الْجُمُعَةِ فَقَالَ كَانَ يَقْرَأُ ‏\{‏ هَلْ أَتَاكَ‏\}‏\hadithno{2030}\hadithtrans{Dahhak b. Qais wrote to Nu'man b. Bashir asking him what the Messenger of Allah (ﷺ) recited on Friday besides Surah Jumu'a He said that he recited:" Has there reached..." (Surah lxxxviii)}}
\hadithdefcmd{muslim}{2031}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ سُفْيَانَ، عَنْ مُخَوَّلِ، بْنِ رَاشِدٍ عَنْ مُسْلِمٍ الْبَطِينِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْرَأُ فِي صَلاَةِ الْفَجْرِ يَوْمَ الْجُمُعَةِ ‏\{‏ الم * تَنْزِيلُ‏\}‏ السَّجْدَةُ وَ ‏\{‏ هَلْ أَتَى عَلَى الإِنْسَانِ حِينٌ مِنَ الدَّهْرِ‏\}‏ وَأَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْرَأُ فِي صَلاَةِ الْجُمُعَةِ سُورَةَ الْجُمُعَةِ وَالْمُنَافِقِينَ ‏.‏\hadithno{2031}\hadithtrans{Ibn Abbas reported:The Apostle of Allah (ﷺ) used to recite in the morning prayer on Friday Surah" Alif-Lam-Mim, Tanz'il ul-Sajda" (Surah xxxii.): Surely there came over the man a time" (Surah lxxvii) and he used to recite in Jumu'a prayer Surahs Jumu'a and al-Munafiqin}}
\hadithdefcmd{muslim}{2032}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، كِلاَهُمَا عَنْ سُفْيَانَ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ ‏.‏\hadithno{2032}\hadithtrans{A hadith like this has been narrated by Sufyan with the same chain of transmitters}}
\hadithdefcmd{muslim}{2033}{وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مُخَوَّلٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ فِي الصَّلاَتَيْنِ كِلْتَيْهِمَا ‏.‏ كَمَا قَالَ سُفْيَانُ\hadithno{2033}\hadithtrans{Mukhawwil has narrated this hadith on the authority of Sufyan}}
\hadithdefcmd{muslim}{2034}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ عَبْدِ، الرَّحْمَنِ الأَعْرَجِ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ أَنَّهُ كَانَ يَقْرَأُ فِي الْفَجْرِ يَوْمَ الْجُمُعَةِ ‏\{‏ الم * تَنْزِيلُ‏\}‏ وَ ‏\{‏ هَلْ أَتَى‏\}‏\hadithno{2034}\hadithtrans{Abu Huraira reported that the Messenger of Allah (ﷺ) used to recite in the dawn prayer on Friday" Alif-Lam-Mim, Tanzil" and" Surely there came}}
\hadithdefcmd{muslim}{2035}{حَدَّثَنِي أَبُو الطَّاهِرِ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ إِبْرَاهِيمَ بْنِ سَعْدٍ، عَنْ أَبِيهِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، ‏.‏ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْرَأُ فِي الصُّبْحِ يَوْمَ الْجُمُعَةِ بِـ ‏\{‏ الم * تَنْزِيلُ‏\}‏ فِي الرَّكْعَةِ الأُولَى وَفِي الثَّانِيَةِ ‏\{‏ هَلْ أَتَى عَلَى الإِنْسَانِ حِينٌ مِنَ الدَّهْرِ لَمْ يَكُنْ شَيْئًا مَذْكُورًا‏\}‏\hadithno{2035}\hadithtrans{Abu Huraira reported that the Messenger of Allah (ﷺ) used to recite in the dawn prayer on Friday:" Alif-Lam-Mim, Tanzil" in the first rak'ah, and in the second one:" Surely there came over the man a time when he was nothing that could be mentioned}}
\hadithdefcmd{muslim}{2036}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي، هُرَيْرَةَ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا صَلَّى أَحَدُكُمُ الْجُمُعَةَ فَلْيُصَلِّ بَعْدَهَا أَرْبَعًا ‏"‏ ‏.‏\hadithno{2036}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:When any one of you observes the Jumu'a prayer (two obligatory rak'ahs in congregation), he should observe four (rak'ahs) afterwards}}
\hadithdefcmd{muslim}{2037}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا صَلَّيْتُمْ بَعْدَ الْجُمُعَةِ فَصَلُّوا أَرْبَعًا ‏"‏ ‏.‏ - زَادَ عَمْرٌو فِي رِوَايَتِهِ قَالَ ابْنُ إِدْرِيسَ قَالَ سُهَيْلٌ فَإِنْ عَجِلَ بِكَ شَىْءٌ فَصَلِّ رَكْعَتَيْنِ فِي الْمَسْجِدِ وَرَكْعَتَيْنِ إِذَا رَجَعْتَ ‏"‏ ‏.‏\hadithno{2037}\hadithtrans{Suhail reported on the authority of Abu Huraira that the Messenger of Allah (ﷺ) said:When you observe prayer after (the two obligatory rak'ahs) of Jumu'ah, you should observe four rak'ahs (and 'Amr in his narration has made this addition that Ibn Idris said this on the authority of Suhail): And if you are in a hurry on account of something, you should observe two rak'ahs in the mosque and two when you return (to your house)}}
\hadithdefcmd{muslim}{2038}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، كِلاَهُمَا عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ كَانَ مِنْكُمْ مُصَلِّيًا بَعْدَ الْجُمُعَةِ فَلْيُصَلِّ أَرْبَعًا ‏"‏ ‏.‏ وَلَيْسَ فِي حَدِيثِ جَرِيرٍ ‏"‏ مِنْكُمْ ‏"‏ ‏.‏\hadithno{2038}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:When any one amongst you observes prayer after Jumu'a, he should observe four rak'ahs. (In the hadith transmitted by Jarir the word minkum is not recorded)}}
\hadithdefcmd{muslim}{2039}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ رُمْحٍ، قَالاَ أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا لَيْثٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، أَنَّهُ كَانَ إِذَا صَلَّى الْجُمُعَةَ انْصَرَفَ فَسَجَدَ سَجْدَتَيْنِ فِي بَيْتِهِ ثُمَّ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصْنَعُ ذَلِكَ ‏.‏\hadithno{2039}\hadithtrans{Nafi' reported that when 'Abdullah (b. 'Umar) observed the Friday prayer and came back he observed two rak'ahs in his house, and then said:The Messenger of Allah (may peace be updn him) used to do this}}
\hadithdefcmd{muslim}{2040}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ وَصَفَ تَطَوُّعَ صَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ فَكَانَ لاَ يُصَلِّي بَعْدَ الْجُمُعَةِ حَتَّى يَنْصَرِفَ فَيُصَلِّي رَكْعَتَيْنِ فِي بَيْتِهِ ‏.‏ قَالَ يَحْيَى أَظُنُّنِي قَرَأْتُ فَيُصَلِّي أَوْ أَلْبَتَّةَ ‏.‏\hadithno{2040}\hadithtrans{Abdullah b. 'Umar, while describing the Nafl prayer of the Messenger of Allah (ﷺ), said:He did not observe (Nafl) prayer after Jumu'a till he went back and observed two rak'ahs in his house. Yahya said: I guess that I uttered these words (before Imam Malik) that he of course observed (them)}}
\hadithdefcmd{muslim}{2041}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَابْنُ، نُمَيْرٍ قَالَ زُهَيْرٌ حَدَّثَنَا سُفْيَانُ، بْنُ عُيَيْنَةَ حَدَّثَنَا عَمْرٌو، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُصَلِّي بَعْدَ الْجُمُعَةِ رَكْعَتَيْنِ ‏.‏\hadithno{2041}\hadithtrans{Salim narrated on the authority of his father that the Messenger of Allah (ﷺ) used to observe two rak'ahs after Jumu'a}}
\hadithdefcmd{muslim}{2042}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي عُمَرُ، بْنُ عَطَاءِ بْنِ أَبِي الْخُوَارِ أَنَّ نَافِعَ بْنَ جُبَيْرٍ، أَرْسَلَهُ إِلَى السَّائِبِ ابْنِ أُخْتِ نَمِرٍ يَسْأَلُهُ عَنْ شَىْءٍ، رَآهُ مِنْهُ مُعَاوِيَةُ فِي الصَّلاَةِ فَقَالَ نَعَمْ ‏.‏ صَلَّيْتُ مَعَهُ الْجُمُعَةَ فِي الْمَقْصُورَةِ فَلَمَّا سَلَّمَ الإِمَامُ قُمْتُ فِي مَقَامِي فَصَلَّيْتُ فَلَمَّا دَخَلَ أَرْسَلَ إِلَىَّ فَقَالَ لاَ تَعُدْ لِمَا فَعَلْتَ إِذَا صَلَّيْتَ الْجُمُعَةَ فَلاَ تَصِلْهَا بِصَلاَةٍ حَتَّى تَكَلَّمَ أَوْ تَخْرُجَ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَنَا بِذَلِكَ أَنْ لاَ تُوصَلَ صَلاَةٌ حَتَّى نَتَكَلَّمَ أَوْ نَخْرُجَ ‏.‏\hadithno{2042}\hadithtrans{Umar b. `Ata' b. Abu Khuwar said that Nafi` b. Jubair sent him to al- Sa'ib the son of Namir's sister to ask him about what he had seen in the prayer of Mu`awiya. He said:Yes, I observed the Jumu`a prayer along with him in Maqsura and when the Imam pronounced salutation I stood up at my place and observed (Sunan rak`ahs). As he entered (the apartment) he sent for me and said: Do not repeat what you have done. Whenever you have observed the Jumu`a prayer, do not observe (Sunan prayer) till you, have talked or gone out, for the Messenger of Allah (ﷺ) had ordered us to do this and not to combine two (types of) prayers without talking or going out}}
\hadithdefcmd{muslim}{2043}{وَحَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي عُمَرُ بْنُ عَطَاءٍ، أَنَّ نَافِعَ بْنَ جُبَيْرٍ، أَرْسَلَهُ إِلَى السَّائِبِ بْنِ يَزِيدَ ابْنِ أُخْتِ نَمِرٍ ‏.‏ وَسَاقَ الْحَدِيثَ بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ فَلَمَّا سَلَّمَ قُمْتُ فِي مَقَامِي وَلَمْ يَذْكُرِ الإِمَامَ ‏.‏\hadithno{2043}\hadithtrans{The same hadith is narrated on the authority of 'Umar b. Ata' but with this modification:When he (the Imam) pronounced salutation I stood up at my place. No mention was made of the Imam in it}}
